@@ -26,7 +26,7 @@ from pygame_menu.locals import POSITION_SOUTHEAST, POSITION_SOUTHWEST, POSITION_
     POSITION_NORTHEAST, POSITION_NORTHWEST, POSITION_CENTER, POSITION_EAST, \
     POSITION_NORTH, ORIENTATION_HORIZONTAL, ORIENTATION_VERTICAL, \
     SCROLLAREA_POSITION_BOTH_HORIZONTAL, POSITION_SOUTH, SCROLLAREA_POSITION_FULL, \
-    SCROLLAREA_POSITION_BOTH_VERTICAL
+    SCROLLAREA_POSITION_BOTH_VERTICAL, SCROLLAREA_POSITION_NONE
 from pygame_menu.utils import make_surface, assert_color, assert_position, \
     assert_orientation, get_finger_pos
 from pygame_menu.widgets import ScrollBar
@@ -63,6 +63,8 @@ def get_scrollbars_from_position(
         return POSITION_SOUTH, POSITION_NORTH
     elif position == SCROLLAREA_POSITION_BOTH_VERTICAL:
         return POSITION_EAST, POSITION_WEST
+    elif position == SCROLLAREA_POSITION_NONE:
+        return ''
     elif position == POSITION_CENTER:
         raise ValueError('cannot init scrollbars from center position')
     else:
@@ -130,7 +132,6 @@ class ScrollArea(Base):
     _parent_scrollarea: 'ScrollArea'
     _rect: 'pygame.Rect'
     _scrollbar_positions: Tuple[str, ...]
-    _scrollbar_thick: int
     _scrollbars: List['ScrollBar']
     _scrollbars_props: Tuple[Any, ...]
     _translate: Tuple2IntType
@@ -216,13 +217,16 @@ class ScrollArea(Base):
                 if s not in unique_scrolls:
                     unique_scrolls.append(s)
 
+        # Remove none position
+        if '' in unique_scrolls:
+            unique_scrolls.pop(unique_scrolls.index(''))
+
         self._area_color = area_color
         self._border_color = border_color
         self._border_width = border_width
         self._bg_surface = None
         self._decorator = Decorator(self)
         self._scrollbar_positions = tuple(unique_scrolls)  # Ensure unique
-        self._scrollbar_thick = scrollbar_thick
         self._translate = (0, 0)
         self._world = world
 
@@ -430,14 +434,14 @@ class ScrollArea(Base):
                 d_size, (dx, dy) = self._menubar.get_scrollbar_style_change(pos)
 
             if pos == POSITION_WEST:
-                sbar.set_position(x=self._view_rect.left - self._scrollbar_thick + dx,
+                sbar.set_position(x=self._view_rect.left - sbar.get_thickness() + dx,
                                   y=self._view_rect.top + dy)
             elif pos == POSITION_EAST:
                 sbar.set_position(x=self._view_rect.right + dx,
                                   y=self._view_rect.top + dy)
             elif pos == POSITION_NORTH:
                 sbar.set_position(x=self._view_rect.left + dx,
-                                  y=self._view_rect.top - self._scrollbar_thick + dy)
+                                  y=self._view_rect.top - sbar.get_thickness() + dy)
             elif pos == POSITION_SOUTH:  # South
                 sbar.set_position(x=self._view_rect.left + dx,
                                   y=self._view_rect.bottom + dy)
@@ -570,6 +574,19 @@ class ScrollArea(Base):
 
         return self
 
+    def get_border_size(self) -> Tuple2IntType:
+        """
+        Return the border size (width, height) in px.
+
+        :return: Border width, height
+        """
+        if isinstance(self._border_color, pygame_menu.BaseImage):  # Image
+            return self._border_tiles_size
+        else:  # Color
+            if self._border_color is None:
+                return 0, 0
+            return self._border_width, self._border_width
+
     def get_hidden_width(self) -> int:
         """
         Return the total width out of the bounds of the viewable area.
@@ -677,82 +694,106 @@ class ScrollArea(Base):
         # All scrollbars: the world is too large
         if self._world.get_height() > self._rect.height \
                 and self._world.get_width() > self._rect.width:
-            if POSITION_WEST in self._scrollbar_positions:
-                rect.left += self._scrollbar_thick
-                rect.width -= self._scrollbar_thick
-            if POSITION_EAST in self._scrollbar_positions:
-                rect.width -= self._scrollbar_thick
-            if POSITION_NORTH in self._scrollbar_positions:
-                rect.top += self._scrollbar_thick
-                rect.height -= self._scrollbar_thick
-            if POSITION_SOUTH in self._scrollbar_positions:
-                rect.height -= self._scrollbar_thick
+            for sbar in self._scrollbars:
+                if not sbar.is_visible():
+                    continue
+                pos = self._scrollbar_positions[self._scrollbars.index(sbar)]
+                thk = sbar.get_thickness()
+                if pos == POSITION_WEST:
+                    rect.left += thk
+                    rect.width -= thk
+                elif pos == POSITION_EAST:
+                    rect.width -= thk
+                elif pos == POSITION_NORTH:
+                    rect.top += thk
+                    rect.height -= thk
+                elif pos == POSITION_SOUTH:
+                    rect.height -= thk
             return rect
 
-        # Calculate the maximum variations introduces by the scrollbars
+        # Calculate the maximum variations introduced by the scrollbars
         bars_total_width = 0
         bars_total_height = 0
-        if POSITION_NORTH in self._scrollbar_positions:
-            bars_total_height += self._scrollbar_thick
-        if POSITION_SOUTH in self._scrollbar_positions:
-            bars_total_height += self._scrollbar_thick
-        if POSITION_WEST in self._scrollbar_positions:
-            bars_total_width += self._scrollbar_thick
-        if POSITION_EAST in self._scrollbar_positions:
-            bars_total_width += self._scrollbar_thick
+        for sbar in self._scrollbars:
+            if not sbar.is_visible():
+                continue
+            pos = self._scrollbar_positions[self._scrollbars.index(sbar)]
+            thk = sbar.get_thickness()
+            if pos in (POSITION_NORTH, POSITION_SOUTH):
+                bars_total_height += thk
+            elif pos in (POSITION_WEST, POSITION_EAST):
+                bars_total_width += thk
 
         if self._world.get_height() > self._rect.height:
-            if POSITION_WEST in self._scrollbar_positions:
-                rect.left += self._scrollbar_thick
-                rect.width -= self._scrollbar_thick
-            if POSITION_EAST in self._scrollbar_positions:
-                rect.width -= self._scrollbar_thick
-            if self._world.get_width() > self._rect.width - bars_total_width:
-                if POSITION_NORTH in self._scrollbar_positions:
-                    rect.top += self._scrollbar_thick
-                    rect.height -= self._scrollbar_thick
-                if POSITION_SOUTH in self._scrollbar_positions:
-                    rect.height -= self._scrollbar_thick
+            for sbar in self._scrollbars:
+                if not sbar.is_visible():
+                    continue
+                pos = self._scrollbar_positions[self._scrollbars.index(sbar)]
+                thk = sbar.get_thickness()
+                if pos == POSITION_WEST:
+                    rect.left += thk
+                    rect.width -= thk
+                elif pos == POSITION_EAST:
+                    rect.width -= thk
+                if self._world.get_width() > self._rect.width - bars_total_width:
+                    if pos == POSITION_NORTH:
+                        rect.top += thk
+                        rect.height -= thk
+                    elif pos == POSITION_SOUTH:
+                        rect.height -= thk
 
         if self._world.get_width() > self._rect.width:
-            if POSITION_NORTH in self._scrollbar_positions:
-                rect.top += self._scrollbar_thick
-                rect.height -= self._scrollbar_thick
-            if POSITION_SOUTH in self._scrollbar_positions:
-                rect.height -= self._scrollbar_thick
-            if self._world.get_height() > self._rect.height - bars_total_height:
-                if POSITION_WEST in self._scrollbar_positions:
-                    rect.left += self._scrollbar_thick
-                    rect.width -= self._scrollbar_thick
-                if POSITION_EAST in self._scrollbar_positions:
-                    rect.width -= self._scrollbar_thick
+            for sbar in self._scrollbars:
+                if not sbar.is_visible():
+                    continue
+                pos = self._scrollbar_positions[self._scrollbars.index(sbar)]
+                thk = sbar.get_thickness()
+                if pos == POSITION_NORTH:
+                    rect.top += thk
+                    rect.height -= thk
+                elif pos == POSITION_SOUTH:
+                    rect.height -= thk
+                if self._world.get_height() > self._rect.height - bars_total_height:
+                    if pos == POSITION_WEST:
+                        rect.left += thk
+                        rect.width -= thk
+                    elif pos == POSITION_EAST:
+                        rect.width -= thk
 
         return rect
 
-    def hide_scrollbars(self, orientation: str) -> 'ScrollArea':
+    def hide_scrollbars(self, orientation: str, force: bool = True) -> 'ScrollArea':
         """
         Hide scrollbar from given orientation.
 
         :param orientation: Orientation. See :py:mod:`pygame_menu.locals`
+        :param force: Force hide
         :return: Self reference
         """
         assert_orientation(orientation)
         for sbar in self._scrollbars:
             if sbar.get_orientation() == orientation:
-                sbar.hide()
+                sbar.hide(force=force)
+                if not force:
+                    sbar.disable_visibility_force()
+        self._apply_size_changes()
         return self
 
-    def show_scrollbars(self, orientation: str) -> 'ScrollArea':
+    def show_scrollbars(self, orientation: str, force: bool = True) -> 'ScrollArea':
         """
         Hide scrollbar from given orientation.
 
         :param orientation: Orientation. See :py:mod:`pygame_menu.locals`
+        :param force: Force show
         :return: Self reference
         """
         assert_orientation(orientation)
         for sbar in self._scrollbars:
             if sbar.get_orientation() == orientation:
-                sbar.show()
+                sbar.show(force=force)
+                if not force:
+                    sbar.disable_visibility_force()
+        self._apply_size_changes()
         return self
 
     def get_world_size(self) -> Tuple2IntType:
